@@ -22,7 +22,6 @@ import (
 	"strconv"
 	"strings"
 
-	textdiff "github.com/andreyvit/diff"
 	"github.com/dolthub/go-mysql-server/sql"
 	"github.com/dolthub/go-mysql-server/sql/types"
 
@@ -43,7 +42,6 @@ import (
 
 type diffOutput int
 type diffPart int
-type diffMode int
 
 const (
 	SchemaOnlyDiff diffPart = 1 // 0b0001
@@ -63,7 +61,6 @@ const (
 	SummaryFlag = "summary"
 	whereParam  = "where"
 	limitParam  = "limit"
-	SQLFlag     = "sql"
 	SkinnyFlag  = "skinny"
 	MergeBase   = "merge-base"
 	DiffMode    = "diff-mode"
@@ -101,20 +98,28 @@ The {{.EmphasisLeft}}--diff-mode{{.EmphasisRight}} argument controls how modifie
 	},
 }
 
-type diffArgs struct {
+type diffDisplaySettings struct {
 	diffParts  diffPart
 	diffOutput diffOutput
 	diffMode   diff.Mode
-	fromRoot   *doltdb.RootValue
-	toRoot     *doltdb.RootValue
-	fromRef    string
-	toRef      string
-	tableSet   *set.StrSet
 	limit      int
 	where      string
 	skinny     bool
 }
 
+type diffDatasets struct {
+	fromRoot *doltdb.RootValue
+	toRoot   *doltdb.RootValue
+	fromRef  string
+	toRef    string
+}
+
+type diffArgs struct {
+	*diffDisplaySettings
+	*diffDatasets
+	tableSet *set.StrSet
+}
+
 type DiffCmd struct{}
 
 // Name is returns the name of the Dolt cli command. This is what is used on the command line to invoke the command
@@ -170,9 +175,6 @@ func (cmd DiffCmd) Exec(ctx context.Context, commandStr string, args []string, d
 	}
 
 	verr = diffUserTables(ctx, dEnv, dArgs)
-	if verr != nil {
-		return HandleVErrAndExitCode(verr, usage)
-	}
 	return HandleVErrAndExitCode(verr, usage)
 }
 
@@ -193,69 +195,89 @@ func (cmd DiffCmd) validateArgs(apr *argparser.ArgParseResults) errhand.VerboseE
 	return nil
 }
 
-func parseDiffArgs(ctx context.Context, dEnv *env.DoltEnv, apr *argparser.ArgParseResults) (*diffArgs, error) {
-	dArgs := &diffArgs{}
+func parseDiffDisplaySettings(ctx context.Context, dEnv *env.DoltEnv, apr *argparser.ArgParseResults) *diffDisplaySettings {
+	displaySettings := &diffDisplaySettings{}
 
-	dArgs.diffParts = SchemaAndDataDiff
+	displaySettings.diffParts = SchemaAndDataDiff
 	if apr.Contains(DataFlag) && !apr.Contains(SchemaFlag) {
-		dArgs.diffParts = DataOnlyDiff
+		displaySettings.diffParts = DataOnlyDiff
 	} else if apr.Contains(SchemaFlag) && !apr.Contains(DataFlag) {
-		dArgs.diffParts = SchemaOnlyDiff
+		displaySettings.diffParts = SchemaOnlyDiff
 	} else if apr.Contains(StatFlag) {
-		dArgs.diffParts = Stat
+		displaySettings.diffParts = Stat
 	} else if apr.Contains(SummaryFlag) {
-		dArgs.diffParts = Summary
+		displaySettings.diffParts = Summary
 	}
 
-	dArgs.skinny = apr.Contains(SkinnyFlag)
+	displaySettings.skinny = apr.Contains(SkinnyFlag)
 
 	f := apr.GetValueOrDefault(FormatFlag, "tabular")
 	switch strings.ToLower(f) {
 	case "tabular":
-		dArgs.diffOutput = TabularDiffOutput
+		displaySettings.diffOutput = TabularDiffOutput
 		switch strings.ToLower(apr.GetValueOrDefault(DiffMode, "context")) {
 		case "row":
-			dArgs.diffMode = diff.ModeRow
+			displaySettings.diffMode = diff.ModeRow
 		case "line":
-			dArgs.diffMode = diff.ModeLine
+			displaySettings.diffMode = diff.ModeLine
 		case "in-place":
-			dArgs.diffMode = diff.ModeInPlace
+			displaySettings.diffMode = diff.ModeInPlace
 		case "context":
-			dArgs.diffMode = diff.ModeContext
+			displaySettings.diffMode = diff.ModeContext
 		}
 	case "sql":
-		dArgs.diffOutput = SQLDiffOutput
+		displaySettings.diffOutput = SQLDiffOutput
 	case "json":
-		dArgs.diffOutput = JsonDiffOutput
+		displaySettings.diffOutput = JsonDiffOutput
 	}
 
-	dArgs.limit, _ = apr.GetInt(limitParam)
-	dArgs.where = apr.GetValueOrDefault(whereParam, "")
+	displaySettings.limit, _ = apr.GetInt(limitParam)
+	displaySettings.where = apr.GetValueOrDefault(whereParam, "")
+
+	return displaySettings
+}
+
+func parseDiffArgs(ctx context.Context, dEnv *env.DoltEnv, apr *argparser.ArgParseResults) (*diffArgs, error) {
+	dArgs := &diffArgs{
+		diffDisplaySettings: parseDiffDisplaySettings(ctx, dEnv, apr),
+	}
 
 	tableNames, err := dArgs.applyDiffRoots(ctx, dEnv, apr.Args, apr.Contains(cli.CachedFlag), apr.Contains(MergeBase))
 	if err != nil {
 		return nil, err
 	}
 
-	dArgs.tableSet = set.NewStrSet(nil)
+	tableSet, err := parseDiffTableSet(ctx, dEnv, dArgs.diffDatasets, tableNames)
+	if err != nil {
+		return nil, err
+	}
+
+	dArgs.tableSet = tableSet
+
+	return dArgs, nil
+}
+
+func parseDiffTableSet(ctx context.Context, dEnv *env.DoltEnv, datasets *diffDatasets, tableNames []string) (*set.StrSet, error) {
+
+	tableSet := set.NewStrSet(nil)
 
 	for _, tableName := range tableNames {
 		// verify table args exist in at least one root
-		_, ok, err := dArgs.fromRoot.GetTable(ctx, tableName)
+		_, ok, err := datasets.fromRoot.GetTable(ctx, tableName)
 		if err != nil {
 			return nil, err
 		}
 		if ok {
-			dArgs.tableSet.Add(tableName)
+			tableSet.Add(tableName)
 			continue
 		}
 
-		_, ok, err = dArgs.toRoot.GetTable(ctx, tableName)
+		_, ok, err = datasets.toRoot.GetTable(ctx, tableName)
 		if err != nil {
 			return nil, err
 		}
 		if ok {
-			dArgs.tableSet.Add(tableName)
+			tableSet.Add(tableName)
 			continue
 		}
 		if !ok {
@@ -265,14 +287,14 @@ func parseDiffArgs(ctx context.Context, dEnv *env.DoltEnv, apr *argparser.ArgPar
 
 	// if no tables or docs were specified as args, diff all tables and docs
 	if len(tableNames) == 0 {
-		utn, err := doltdb.UnionTableNames(ctx, dArgs.fromRoot, dArgs.toRoot)
+		utn, err := doltdb.UnionTableNames(ctx, datasets.fromRoot, datasets.toRoot)
 		if err != nil {
 			return nil, err
 		}
-		dArgs.tableSet.Add(utn...)
+		tableSet.Add(utn...)
 	}
 
-	return dArgs, nil
+	return tableSet, nil
 }
 
 // applyDiffRoots applies the appropriate |from| and |to| root values to the receiver and returns the table names
@@ -293,10 +315,13 @@ func (dArgs *diffArgs) applyDiffRoots(ctx context.Context, dEnv *env.DoltEnv, ar
 		return nil, err
 	}
 
-	dArgs.fromRoot = stagedRoot
-	dArgs.fromRef = doltdb.Staged
-	dArgs.toRoot = workingRoot
-	dArgs.toRef = doltdb.Working
+	dArgs.diffDatasets = &diffDatasets{
+		fromRoot: stagedRoot,
+		fromRef:  doltdb.Staged,
+		toRoot:   workingRoot,
+		toRef:    doltdb.Working,
+	}
+
 	if isCached {
 		dArgs.fromRoot = headRoot
 		dArgs.fromRef = "HEAD"
@@ -526,21 +551,27 @@ func diffUserTables(ctx context.Context, dEnv *env.DoltEnv, dArgs *diffArgs) err
 		return errhand.VerboseErrorFromError(err)
 	}
 
+	doltSchemasChanged := false
 	for _, td := range tableDeltas {
-		if !dArgs.tableSet.Contains(td.FromName) && !dArgs.tableSet.Contains(td.ToName) {
+		if !shouldPrintTableDelta(dArgs.tableSet, td) {
 			continue
 		}
-		if strings.ToLower(td.ToName) != doltdb.SchemasTableName {
+
+		if isDoltSchemasTable(td) {
+			// save dolt_schemas table diff for last in diff output
+			doltSchemasChanged = true
+		} else {
 			verr := diffUserTable(sqlCtx, td, sqlEng, dArgs, dw)
 			if verr != nil {
 				return verr
 			}
-		} else {
-			// dolt_schemas table is treated as a special case. diff the rows of the table, and print fragments as DDL
-			verr := diffDoltSchemasTable(sqlCtx, td, sqlEng, dArgs, dw)
-			if verr != nil {
-				return verr
-			}
+		}
+	}
+
+	if doltSchemasChanged {
+		verr := diffDoltSchemasTable(sqlCtx, sqlEng, dArgs, dw)
+		if verr != nil {
+			return verr
 		}
 	}
 
@@ -552,6 +583,15 @@ func diffUserTables(ctx context.Context, dEnv *env.DoltEnv, dArgs *diffArgs) err
 	return nil
 }
 
+func shouldPrintTableDelta(tablesToPrint *set.StrSet, td diff.TableDelta) bool {
+	// TODO: this should be case insensitive
+	return tablesToPrint.Contains(td.FromName) || tablesToPrint.Contains(td.ToName)
+}
+
+func isDoltSchemasTable(td diff.TableDelta) bool {
+	return td.FromName == doltdb.SchemasTableName || td.ToName == doltdb.SchemasTableName
+}
+
 func diffUserTable(
 	ctx *sql.Context,
 	td diff.TableDelta,
@@ -581,7 +621,7 @@ func diffUserTable(
 	}
 
 	if dArgs.diffParts&SchemaOnlyDiff != 0 {
-		err := dw.WriteSchemaDiff(ctx, dArgs.toRoot, td)
+		err := dw.WriteTableSchemaDiff(ctx, dArgs.toRoot, td)
 		if err != nil {
 			return errhand.VerboseErrorFromError(err)
 		}
@@ -603,17 +643,14 @@ func diffUserTable(
 
 func diffDoltSchemasTable(
 	sqlCtx *sql.Context,
-	td diff.TableDelta,
 	sqlEng *engine.SqlEngine,
 	dArgs *diffArgs,
 	dw diffWriter,
 ) errhand.VerboseError {
-	err := dw.BeginTable(sqlCtx, td)
-	if err != nil {
-		return errhand.VerboseErrorFromError(err)
-	}
-
-	query := fmt.Sprintf("select from_fragment,to_fragment from dolt_diff('%s','%s','%s')", dArgs.fromRef, dArgs.toRef, doltdb.SchemasTableName)
+	query := fmt.Sprintf("select from_name,to_name,from_type,to_type,from_fragment,to_fragment "+
+		"from dolt_diff('%s','%s','%s') "+
+		"order by coalesce(from_type, to_type), coalesce(from_name, to_name)",
+		dArgs.fromRef, dArgs.toRef, doltdb.SchemasTableName)
 
 	_, rowIter, err := sqlEng.Query(sqlCtx, query)
 	if err != nil {
@@ -629,30 +666,52 @@ func diffDoltSchemasTable(
 			return errhand.VerboseErrorFromError(err)
 		}
 
-		from := ""
+		var fragmentName string
 		if row[0] != nil {
-			from = fmt.Sprintf("%v;", row[0])
+			fragmentName = row[0].(string)
+		} else {
+			fragmentName = row[1].(string)
 		}
-		to := ""
-		if row[1] != nil {
-			to = fmt.Sprintf("%v;", row[1])
+
+		var fragmentType string
+		if row[2] != nil {
+			fragmentType = row[2].(string)
+		} else {
+			fragmentType = row[3].(string)
 		}
-		if from != to {
-			cli.Println(textdiff.LineDiff(from, to))
+
+		var oldFragment string
+		var newFragment string
+		if row[4] != nil {
+			oldFragment = row[4].(string)
+			// Typically schema fragements have the semicolons stripped, so put it back on
+			if len(oldFragment) > 0 && oldFragment[len(oldFragment)-1] != ';' {
+				oldFragment += ";"
+			}
+		}
+		if row[5] != nil {
+			newFragment = row[5].(string)
+			// Typically schema fragements have the semicolons stripped, so put it back on
+			if len(newFragment) > 0 && newFragment[len(newFragment)-1] != ';' {
+				newFragment += ";"
+			}
 		}
-	}
 
-	return nil
-}
-
-func writeSqlSchemaDiff(ctx context.Context, td diff.TableDelta, toSchemas map[string]schema.Schema) errhand.VerboseError {
-	ddlStatements, err := diff.SqlSchemaDiff(ctx, td, toSchemas)
-	if err != nil {
-		return errhand.VerboseErrorFromError(err)
-	}
-
-	for _, stmt := range ddlStatements {
-		cli.Println(stmt)
+		switch fragmentType {
+		case "view":
+			err := dw.WriteViewDiff(sqlCtx, fragmentName, oldFragment, newFragment)
+			if err != nil {
+				return nil
+			}
+		case "trigger":
+			err := dw.WriteTriggerDiff(sqlCtx, fragmentName, oldFragment, newFragment)
+			if err != nil {
+				return nil
+			}
+		default:
+			cli.PrintErrf("Unrecognized schema element type: %s", fragmentType)
+			continue
+		}
 	}
 
 	return nil
