@@ -24,9 +24,8 @@ import (
 	"time"
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/dbfactory"
-	"github.com/dolthub/dolt/go/libraries/utils/filesys"
-
 	"github.com/dolthub/dolt/go/libraries/doltcore/ref"
+	"github.com/dolthub/dolt/go/libraries/utils/filesys"
 	"github.com/dolthub/dolt/go/store/chunks"
 	"github.com/dolthub/dolt/go/store/datas"
 	"github.com/dolthub/dolt/go/store/datas/pull"
@@ -143,11 +142,11 @@ func (ddb *DoltDB) CSMetricsSummary() string {
 // WriteEmptyRepo will create initialize the given db with a master branch which points to a commit which has valid
 // metadata for the creation commit, and an empty RootValue.
 func (ddb *DoltDB) WriteEmptyRepo(ctx context.Context, initBranch, name, email string) error {
-	return ddb.WriteEmptyRepoWithCommitTime(ctx, initBranch, name, email, datas.CommitNowFunc())
+	return ddb.WriteEmptyRepoWithCommitMetaGenerator(ctx, initBranch, datas.MakeCommitMetaGenerator(name, email, datas.CommitNowFunc()))
 }
 
-func (ddb *DoltDB) WriteEmptyRepoWithCommitTime(ctx context.Context, initBranch, name, email string, t time.Time) error {
-	return ddb.WriteEmptyRepoWithCommitTimeAndDefaultBranch(ctx, name, email, t, ref.NewBranchRef(initBranch))
+func (ddb *DoltDB) WriteEmptyRepoWithCommitMetaGenerator(ctx context.Context, initBranch string, commitMeta datas.CommitMetaGenerator) error {
+	return ddb.WriteEmptyRepoWithCommitMetaGeneratorAndDefaultBranch(ctx, commitMeta, ref.NewBranchRef(initBranch))
 }
 
 func (ddb *DoltDB) WriteEmptyRepoWithCommitTimeAndDefaultBranch(
@@ -156,14 +155,14 @@ func (ddb *DoltDB) WriteEmptyRepoWithCommitTimeAndDefaultBranch(
 	t time.Time,
 	init ref.BranchRef,
 ) error {
-	// precondition checks
-	name = strings.TrimSpace(name)
-	email = strings.TrimSpace(email)
-
-	if name == "" || email == "" {
-		panic("Passed bad name or email.  Both should be valid")
-	}
+	return ddb.WriteEmptyRepoWithCommitMetaGeneratorAndDefaultBranch(ctx, datas.MakeCommitMetaGenerator(name, email, t), init)
+}
 
+func (ddb *DoltDB) WriteEmptyRepoWithCommitMetaGeneratorAndDefaultBranch(
+	ctx context.Context,
+	commitMetaGenerator datas.CommitMetaGenerator,
+	init ref.BranchRef,
+) error {
 	ds, err := ddb.db.GetDataset(ctx, CreationBranch)
 
 	if err != nil {
@@ -186,18 +185,32 @@ func (ddb *DoltDB) WriteEmptyRepoWithCommitTimeAndDefaultBranch(
 		return err
 	}
 
-	cm, _ := datas.NewCommitMetaWithUserTS(name, email, "Initialize data repository", t)
+	var firstCommit *datas.Commit
+	for {
+		cm, err := commitMetaGenerator.Next()
+		if err != nil {
+			return err
+		}
 
-	commitOpts := datas.CommitOptions{Meta: cm}
+		commitOpts := datas.CommitOptions{Meta: cm}
 
-	cb := ref.NewInternalRef(CreationBranch)
-	ds, err = ddb.db.GetDataset(ctx, cb.String())
+		cb := ref.NewInternalRef(CreationBranch)
+		ds, err = ddb.db.GetDataset(ctx, cb.String())
+		if err != nil {
+			return err
+		}
 
-	if err != nil {
-		return err
+		firstCommit, err = ddb.db.BuildNewCommit(ctx, ds, rv.nomsValue(), commitOpts)
+		if err != nil {
+			return err
+		}
+
+		if commitMetaGenerator.IsGoodCommit(firstCommit) {
+			break
+		}
 	}
 
-	firstCommit, err := ddb.db.Commit(ctx, ds, rv.nomsValue(), commitOpts)
+	firstCommitDs, err := ddb.db.WriteCommit(ctx, ds, firstCommit)
 
 	if err != nil {
 		return err
@@ -209,7 +222,7 @@ func (ddb *DoltDB) WriteEmptyRepoWithCommitTimeAndDefaultBranch(
 		return err
 	}
 
-	headAddr, ok := firstCommit.MaybeHeadAddr()
+	headAddr, ok := firstCommitDs.MaybeHeadAddr()
 	if !ok {
 		return errors.New("commit without head")
 	}
@@ -222,12 +235,12 @@ func (ddb *DoltDB) Close() error {
 	return ddb.db.Close()
 }
 
-func getCommitValForRefStr(ctx context.Context, db datas.Database, vrw types.ValueReadWriter, ref string) (*datas.Commit, error) {
+func (ddb *DoltDB) GetHashForRefStr(ctx context.Context, ref string) (*hash.Hash, error) {
 	if err := datas.ValidateDatasetId(ref); err != nil {
 		return nil, fmt.Errorf("invalid ref format: %s", ref)
 	}
 
-	ds, err := db.GetDataset(ctx, ref)
+	ds, err := ddb.db.GetDataset(ctx, ref)
 
 	if err != nil {
 		return nil, err
@@ -238,18 +251,28 @@ func getCommitValForRefStr(ctx context.Context, db datas.Database, vrw types.Val
 	}
 
 	if ds.IsTag() {
-		_, commitaddr, err := ds.HeadTag()
+		_, commitHash, err := ds.HeadTag()
 		if err != nil {
 			return nil, err
 		}
-		return datas.LoadCommitAddr(ctx, vrw, commitaddr)
+		return &commitHash, nil
+	} else {
+		commitHash, ok := ds.MaybeHeadAddr()
+		if !ok {
+			return nil, fmt.Errorf("Unable to load head for %s", ref)
+		}
+		return &commitHash, nil
 	}
+}
+
+func getCommitValForRefStr(ctx context.Context, ddb *DoltDB, ref string) (*datas.Commit, error) {
+	commitHash, err := ddb.GetHashForRefStr(ctx, ref)
 
-	r, _, err := ds.MaybeHeadRef()
 	if err != nil {
 		return nil, err
 	}
-	return datas.LoadCommitRef(ctx, vrw, r)
+
+	return datas.LoadCommitAddr(ctx, ddb.vrw, *commitHash)
 }
 
 func getCommitValForHash(ctx context.Context, vr types.ValueReader, c string) (*datas.Commit, error) {
@@ -311,7 +334,7 @@ func (ddb *DoltDB) Resolve(ctx context.Context, cs *CommitSpec, cwb ref.DoltRef)
 			}
 		}
 		for _, candidate := range candidates {
-			commitVal, err = getCommitValForRefStr(ctx, ddb.db, ddb.vrw, candidate)
+			commitVal, err = getCommitValForRefStr(ctx, ddb, candidate)
 			if err == nil {
 				break
 			}
@@ -325,7 +348,7 @@ func (ddb *DoltDB) Resolve(ctx context.Context, cs *CommitSpec, cwb ref.DoltRef)
 		if cwb == nil {
 			return nil, fmt.Errorf("cannot use a nil current working branch with a HEAD commit spec")
 		}
-		commitVal, err = getCommitValForRefStr(ctx, ddb.db, ddb.vrw, cwb.String())
+		commitVal, err = getCommitValForRefStr(ctx, ddb, cwb.String())
 	default:
 		panic("unrecognized commit spec csType: " + cs.csType)
 	}
@@ -344,7 +367,7 @@ func (ddb *DoltDB) Resolve(ctx context.Context, cs *CommitSpec, cwb ref.DoltRef)
 // ResolveCommitRef takes a DoltRef and returns a Commit, or an error if the commit cannot be found. The ref given must
 // point to a Commit.
 func (ddb *DoltDB) ResolveCommitRef(ctx context.Context, ref ref.DoltRef) (*Commit, error) {
-	commitVal, err := getCommitValForRefStr(ctx, ddb.db, ddb.vrw, ref.String())
+	commitVal, err := getCommitValForRefStr(ctx, ddb, ref.String())
 	if err != nil {
 		return nil, err
 	}
@@ -1211,7 +1234,16 @@ func (ddb *DoltDB) Rebase(ctx context.Context) error {
 }
 
 // GC performs garbage collection on this ddb.
-func (ddb *DoltDB) GC(ctx context.Context) error {
+//
+// If |safepointF| is non-nil, it will be called at some point after the GC begins
+// and before the GC ends. It will be called without
+// Database/ValueStore/NomsBlockStore locks held. If should establish
+// safepoints in every application-level in-progress read and write workflow
+// against this DoltDB. Examples of doing this include, for example, blocking
+// until no possibly-stale ChunkStore state is retained in memory, or failing
+// certain in-progress operations which cannot be finalized in a timely manner,
+// etc.
+func (ddb *DoltDB) GC(ctx context.Context, safepointF func() error) error {
 	collector, ok := ddb.db.Database.(datas.GarbageCollector)
 	if !ok {
 		return fmt.Errorf("this database does not support garbage collection")
@@ -1255,7 +1287,7 @@ func (ddb *DoltDB) GC(ctx context.Context) error {
 		return err
 	}
 
-	return collector.GC(ctx, oldGen, newGen)
+	return collector.GC(ctx, oldGen, newGen, safepointF)
 }
 
 func (ddb *DoltDB) ShallowGC(ctx context.Context) error {
