@@ -34,7 +34,62 @@ import (
 	"github.com/dolthub/dolt/go/store/val"
 )
 
-func prollyParentFkConstraintViolations(
+func prollyParentSecDiffFkConstraintViolations(
+	ctx context.Context,
+	foreignKey doltdb.ForeignKey,
+	postParent, postChild *constraintViolationsLoadedTable,
+	preParentSecIdx prolly.Map,
+	receiver FKViolationReceiver) error {
+
+	postParentRowData := durable.ProllyMapFromIndex(postParent.RowData)
+	postParentSecIdx := durable.ProllyMapFromIndex(postParent.IndexData)
+	childSecIdx := durable.ProllyMapFromIndex(postChild.IndexData)
+
+	parentSecKD, _ := postParentSecIdx.Descriptors()
+	parentPrefixKD := parentSecKD.PrefixDesc(len(foreignKey.TableColumns))
+	partialKB := val.NewTupleBuilder(parentPrefixKD)
+
+	childPriIdx := durable.ProllyMapFromIndex(postChild.RowData)
+	childPriKD, _ := childPriIdx.Descriptors()
+
+	var err error
+	err = prolly.DiffMaps(ctx, preParentSecIdx, postParentSecIdx, func(ctx context.Context, diff tree.Diff) error {
+		switch diff.Type {
+		case tree.RemovedDiff, tree.ModifiedDiff:
+			toSecKey, hadNulls := makePartialKey(partialKB, foreignKey.ReferencedTableColumns, postParent.Index, postParent.IndexSchema, val.Tuple(diff.Key), val.Tuple(diff.From), preParentSecIdx.Pool())
+			if hadNulls {
+				// row had some nulls previously, so it couldn't have been a parent
+				return nil
+			}
+
+			ok, err := postParentSecIdx.HasPrefix(ctx, toSecKey, parentPrefixKD)
+			if err != nil {
+				return err
+			}
+			if ok {
+				return nil
+			}
+
+			// All equivalent parents were deleted, let's check for dangling children.
+			// We search for matching keys in the child's secondary index
+			err = createCVsForPartialKeyMatches(ctx, toSecKey, parentPrefixKD, childPriKD, childPriIdx, childSecIdx, postParentRowData.Pool(), receiver)
+			if err != nil {
+				return err
+			}
+		case tree.AddedDiff:
+		default:
+			panic("unhandled diff type")
+		}
+		return nil
+	})
+	if err != nil && err != io.EOF {
+		return err
+	}
+
+	return nil
+}
+
+func prollyParentPriDiffFkConstraintViolations(
 	ctx context.Context,
 	foreignKey doltdb.ForeignKey,
 	postParent, postChild *constraintViolationsLoadedTable,
@@ -153,11 +208,10 @@ func prollyChildSecDiffFkConstraintViolations(
 	parentSecIdx := durable.ProllyMapFromIndex(postParent.IndexData)
 
 	parentSecIdxDesc, _ := parentSecIdx.Descriptors()
-	partialDesc := parentSecIdxDesc.PrefixDesc(len(foreignKey.TableColumns))
+	prefixDesc := parentSecIdxDesc.PrefixDesc(len(foreignKey.TableColumns))
 	childPriKD, _ := postChildRowData.Descriptors()
 	childPriKB := val.NewTupleBuilder(childPriKD)
 
-	var parentSecIdxCur *tree.Cursor
 	err := prolly.DiffMaps(ctx, preChildSecIdx, postChildSecIdx, func(ctx context.Context, diff tree.Diff) error {
 		switch diff.Type {
 		case tree.AddedDiff, tree.ModifiedDiff:
@@ -169,31 +223,14 @@ func prollyChildSecDiffFkConstraintViolations(
 				}
 			}
 
-			if parentSecIdxCur == nil {
-				newCur, err := tree.NewCursorAtKey(ctx, parentSecIdx.NodeStore(), parentSecIdx.Node(), k, partialDesc)
-				if err != nil {
-					return err
-				}
-				if !newCur.Valid() {
-					return createCVForSecIdx(ctx, k, childPriKD, childPriKB, postChildRowData, postChildRowData.Pool(), receiver)
-				}
-				parentSecIdxCur = newCur
-			}
-
-			err := tree.Seek(ctx, parentSecIdxCur, k, partialDesc)
+			ok, err := parentSecIdx.HasPrefix(ctx, k, prefixDesc)
 			if err != nil {
 				return err
-			}
-			if !parentSecIdxCur.Valid() {
-				return createCVForSecIdx(ctx, k, childPriKD, childPriKB, postChildRowData, postChildRowData.Pool(), receiver)
-			}
-
-			// possible that k is less than the smallest key in parentSecIdxCur, so still should compare
-			key := val.Tuple(parentSecIdxCur.CurrentKey())
-			if partialDesc.Compare(k, key) != 0 {
+			} else if !ok {
 				return createCVForSecIdx(ctx, k, childPriKD, childPriKB, postChildRowData, postChildRowData.Pool(), receiver)
 			}
 			return nil
+
 		case tree.RemovedDiff:
 		default:
 			panic("unhandled diff type")
@@ -203,7 +240,6 @@ func prollyChildSecDiffFkConstraintViolations(
 	if err != nil && err != io.EOF {
 		return err
 	}
-
 	return nil
 }
 
