@@ -24,7 +24,7 @@ import (
 	"unicode/utf8"
 
 	"github.com/dolthub/go-mysql-server/sql"
-	types2 "github.com/dolthub/go-mysql-server/sql/types"
+	gmstypes "github.com/dolthub/go-mysql-server/sql/types"
 	"github.com/dolthub/vitess/go/sqltypes"
 
 	"github.com/dolthub/dolt/go/store/types"
@@ -37,12 +37,12 @@ const (
 // This is a dolt implementation of the MySQL type Bit, thus most of the functionality
 // within is directly reliant on the go-mysql-server implementation.
 type bitType struct {
-	sqlBitType types2.BitType
+	sqlBitType gmstypes.BitType
 }
 
 var _ TypeInfo = (*bitType)(nil)
 
-var PseudoBoolType TypeInfo = &bitType{types2.MustCreateBitType(1)}
+var PseudoBoolType TypeInfo = &bitType{gmstypes.MustCreateBitType(1)}
 
 func CreateBitTypeFromParams(params map[string]string) (TypeInfo, error) {
 	if bitStr, ok := params[bitTypeParam_Bits]; ok {
@@ -50,7 +50,7 @@ func CreateBitTypeFromParams(params map[string]string) (TypeInfo, error) {
 		if err != nil {
 			return nil, err
 		}
-		sqlBitType, err := types2.CreateBitType(uint8(bitUint))
+		sqlBitType, err := gmstypes.CreateBitType(uint8(bitUint))
 		if err != nil {
 			return nil, err
 		}
@@ -163,7 +163,7 @@ func (ti *bitType) NomsKind() types.NomsKind {
 
 // Promote implements TypeInfo interface.
 func (ti *bitType) Promote() TypeInfo {
-	return &bitType{ti.sqlBitType.Promote().(types2.BitType)}
+	return &bitType{ti.sqlBitType.Promote().(gmstypes.BitType)}
 }
 
 // String implements TypeInfo interface.
@@ -199,7 +199,7 @@ func bitTypeConverter(ctx context.Context, src *bitType, destTi TypeInfo) (tc Ty
 				return nil, fmt.Errorf("unexpected type converting bit to %s: %T", strings.ToLower(dest.String()), v)
 			}
 			if val == 0 {
-				return types.Timestamp(types2.Datetime.Zero().(time.Time)), nil
+				return types.Timestamp(gmstypes.Datetime.Zero().(time.Time)), nil
 			}
 			return nil, fmt.Errorf("invalid %s value: %d", strings.ToLower(dest.String()), uint64(val))
 		}, true, nil
