@@ -20,7 +20,7 @@ import (
 	"strconv"
 
 	"github.com/dolthub/go-mysql-server/sql"
-	types2 "github.com/dolthub/go-mysql-server/sql/types"
+	gmstypes "github.com/dolthub/go-mysql-server/sql/types"
 
 	"github.com/dolthub/dolt/go/store/types"
 )
@@ -28,12 +28,12 @@ import (
 // This is a dolt implementation of the MySQL type Point, thus most of the functionality
 // within is directly reliant on the go-mysql-server implementation.
 type geomcollType struct {
-	sqlGeomCollType types2.GeomCollType
+	sqlGeomCollType gmstypes.GeomCollType
 }
 
 var _ TypeInfo = (*geomcollType)(nil)
 
-var GeomCollType = &geomcollType{types2.GeomCollType{}}
+var GeomCollType = &geomcollType{gmstypes.GeomCollType{}}
 
 // ConvertNomsValueToValue implements TypeInfo interface.
 func (ti *geomcollType) ConvertNomsValueToValue(v types.Value) (interface{}, error) {
@@ -79,7 +79,7 @@ func (ti *geomcollType) ConvertValueToNomsValue(ctx context.Context, vrw types.V
 		return nil, err
 	}
 
-	return types.ConvertSQLGeomCollToTypesGeomColl(geomColl.(types2.GeomColl)), nil
+	return types.ConvertSQLGeomCollToTypesGeomColl(geomColl.(gmstypes.GeomColl)), nil
 }
 
 // Equals implements TypeInfo interface.
@@ -136,7 +136,7 @@ func (ti *geomcollType) NomsKind() types.NomsKind {
 
 // Promote implements TypeInfo interface.
 func (ti *geomcollType) Promote() TypeInfo {
-	return &geomcollType{ti.sqlGeomCollType.Promote().(types2.GeomCollType)}
+	return &geomcollType{ti.sqlGeomCollType.Promote().(gmstypes.GeomCollType)}
 }
 
 // String implements TypeInfo interface.
@@ -228,5 +228,5 @@ func CreateGeomCollTypeFromParams(params map[string]string) (TypeInfo, error) {
 		}
 	}
 
-	return &geomcollType{sqlGeomCollType: types2.GeomCollType{SRID: uint32(sridVal), DefinedSRID: def}}, nil
+	return &geomcollType{sqlGeomCollType: gmstypes.GeomCollType{SRID: uint32(sridVal), DefinedSRID: def}}, nil
 }
