@@ -20,7 +20,7 @@ import (
 	"strconv"
 
 	"github.com/dolthub/go-mysql-server/sql"
-	types2 "github.com/dolthub/go-mysql-server/sql/types"
+	gmstypes "github.com/dolthub/go-mysql-server/sql/types"
 
 	"github.com/dolthub/dolt/go/store/types"
 )
@@ -28,12 +28,12 @@ import (
 // This is a dolt implementation of the MySQL type Point, thus most of the functionality
 // within is directly reliant on the go-mysql-server implementation.
 type multipointType struct {
-	sqlMultiPointType types2.MultiPointType
+	sqlMultiPointType gmstypes.MultiPointType
 }
 
 var _ TypeInfo = (*multipointType)(nil)
 
-var MultiPointType = &multipointType{types2.MultiPointType{}}
+var MultiPointType = &multipointType{gmstypes.MultiPointType{}}
 
 // ConvertNomsValueToValue implements TypeInfo interface.
 func (ti *multipointType) ConvertNomsValueToValue(v types.Value) (interface{}, error) {
@@ -79,7 +79,7 @@ func (ti *multipointType) ConvertValueToNomsValue(ctx context.Context, vrw types
 		return nil, err
 	}
 
-	return types.ConvertSQLMultiPointToTypesMultiPoint(multipoint.(types2.MultiPoint)), nil
+	return types.ConvertSQLMultiPointToTypesMultiPoint(multipoint.(gmstypes.MultiPoint)), nil
 }
 
 // Equals implements TypeInfo interface.
@@ -136,7 +136,7 @@ func (ti *multipointType) NomsKind() types.NomsKind {
 
 // Promote implements TypeInfo interface.
 func (ti *multipointType) Promote() TypeInfo {
-	return &multipointType{ti.sqlMultiPointType.Promote().(types2.MultiPointType)}
+	return &multipointType{ti.sqlMultiPointType.Promote().(gmstypes.MultiPointType)}
 }
 
 // String implements TypeInfo interface.
@@ -227,5 +227,5 @@ func CreateMultiPointTypeFromParams(params map[string]string) (TypeInfo, error)
 			return nil, err
 		}
 	}
-	return &multipointType{sqlMultiPointType: types2.MultiPointType{SRID: uint32(sridVal), DefinedSRID: def}}, nil
+	return &multipointType{sqlMultiPointType: gmstypes.MultiPointType{SRID: uint32(sridVal), DefinedSRID: def}}, nil
 }
