@@ -20,7 +20,7 @@ import (
 	"strconv"
 
 	"github.com/dolthub/go-mysql-server/sql"
-	types2 "github.com/dolthub/go-mysql-server/sql/types"
+	gmstypes "github.com/dolthub/go-mysql-server/sql/types"
 
 	"github.com/dolthub/dolt/go/store/types"
 )
@@ -28,12 +28,12 @@ import (
 // This is a dolt implementation of the MySQL type Point, thus most of the functionality
 // within is directly reliant on the go-mysql-server implementation.
 type pointType struct {
-	sqlPointType types2.PointType
+	sqlPointType gmstypes.PointType
 }
 
 var _ TypeInfo = (*pointType)(nil)
 
-var PointType = &pointType{types2.PointType{}}
+var PointType = &pointType{gmstypes.PointType{}}
 
 // ConvertNomsValueToValue implements TypeInfo interface.
 func (ti *pointType) ConvertNomsValueToValue(v types.Value) (interface{}, error) {
@@ -79,7 +79,7 @@ func (ti *pointType) ConvertValueToNomsValue(ctx context.Context, vrw types.Valu
 		return nil, err
 	}
 
-	return types.ConvertSQLPointToTypesPoint(point.(types2.Point)), nil
+	return types.ConvertSQLPointToTypesPoint(point.(gmstypes.Point)), nil
 }
 
 // Equals implements TypeInfo interface.
@@ -136,7 +136,7 @@ func (ti *pointType) NomsKind() types.NomsKind {
 
 // Promote implements TypeInfo interface.
 func (ti *pointType) Promote() TypeInfo {
-	return &pointType{ti.sqlPointType.Promote().(types2.PointType)}
+	return &pointType{ti.sqlPointType.Promote().(gmstypes.PointType)}
 }
 
 // String implements TypeInfo interface.
@@ -228,5 +228,5 @@ func CreatePointTypeFromParams(params map[string]string) (TypeInfo, error) {
 		}
 	}
 
-	return &pointType{sqlPointType: types2.PointType{SRID: uint32(sridVal), DefinedSRID: def}}, nil
+	return &pointType{sqlPointType: gmstypes.PointType{SRID: uint32(sridVal), DefinedSRID: def}}, nil
 }
