@@ -20,6 +20,8 @@ import (
 	"sync"
 	"time"
 
+	"github.com/dolthub/dolt/go/libraries/doltcore/sqlserver"
+
 	"github.com/dolthub/go-mysql-server/sql"
 	"github.com/dolthub/go-mysql-server/sql/binlogreplication"
 	"github.com/dolthub/go-mysql-server/sql/mysql_db"
@@ -27,6 +29,11 @@ import (
 
 var DoltBinlogReplicaController = newDoltBinlogReplicaController()
 
+// binlogApplierUser is the locked, super user account that is used to execute replicated SQL statements.
+// We cannot always assume the root account will exist, so we automatically create this account that is
+// specific to binlog replication and lock it so that it cannot be used to login.
+const binlogApplierUser = "dolt-binlog-applier"
+
 // ErrServerNotConfiguredAsReplica is returned when replication is started without enough configuration provided.
 var ErrServerNotConfiguredAsReplica = fmt.Errorf(
 	"server is not configured as a replica; fix with CHANGE REPLICATION SOURCE TO")
@@ -123,11 +130,60 @@ func (d *doltBinlogReplicaController) StartReplica(ctx *sql.Context) error {
 		return fmt.Errorf("no execution context set for the replica controller")
 	}
 
+	err = d.configureReplicationUser(ctx)
+	if err != nil {
+		return err
+	}
+
+	// Set execution context's user to the binlog replication user
+	d.ctx.SetClient(sql.Client{
+		User:    binlogApplierUser,
+		Address: "localhost",
+	})
+
 	ctx.GetLogger().Info("starting binlog replication...")
 	d.applier.Go(d.ctx)
 	return nil
 }
 
+// configureReplicationUser creates or configures the super user account needed to apply replication
+// changes and execute DDL statements on the running server. If the account doesn't exist, it will be
+// created and locked to disable log ins, and if it does exist, but is missing super privs or is not
+// locked, it will be given super user privs and locked.
+func (d *doltBinlogReplicaController) configureReplicationUser(ctx *sql.Context) error {
+	server := sqlserver.GetRunningServer()
+	if server == nil {
+		return fmt.Errorf("unable to access a running SQL server")
+	}
+	mySQLDb := server.Engine.Analyzer.Catalog.MySQLDb
+
+	replicationUser := mySQLDb.GetUser(binlogApplierUser, "localhost", false)
+	if replicationUser == nil {
+		// If the replication user doesn't exist yet, create it and lock it
+		mySQLDb.AddSuperUser(binlogApplierUser, "localhost", "")
+		replicationUser := mySQLDb.GetUser(binlogApplierUser, "localhost", false)
+		if replicationUser == nil {
+			return fmt.Errorf("unable to load replication user")
+		}
+		// Make sure this account is locked so that it cannot be used to log in
+		replicationUser.Locked = true
+		err := mySQLDb.UserTable().Data().Put(ctx, replicationUser)
+		if err != nil {
+			return err
+		}
+	} else if replicationUser.IsSuperUser == false || replicationUser.Locked == false {
+		// Fix the replication user if it has been modified
+		replicationUser.IsSuperUser = true
+		replicationUser.Locked = true
+		err := mySQLDb.UserTable().Data().Put(ctx, replicationUser)
+		if err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
 // SetExecutionContext sets the unique |ctx| for the replica's applier to use when applying changes from binlog events
 // to a database. The applier cannot reuse any existing context, because it executes in a separate routine and would
 // cause race conditions.
