@@ -16,7 +16,6 @@ package sqle
 
 import (
 	"fmt"
-	"io"
 	"strings"
 
 	"github.com/dolthub/go-mysql-server/sql"
@@ -76,9 +75,9 @@ func (dtf *DiffTableFunction) Database() sql.Database {
 
 // WithDatabase implements the sql.Databaser interface
 func (dtf *DiffTableFunction) WithDatabase(database sql.Database) (sql.Node, error) {
-	dtf.database = database
-
-	return dtf, nil
+	ndtf := *dtf
+	ndtf.database = database
+	return &ndtf, nil
 }
 
 // Expressions implements the sql.Expressioner interface
@@ -112,32 +111,33 @@ func (dtf *DiffTableFunction) WithExpressions(expression ...sql.Expression) (sql
 		}
 	}
 
+	newDtf := *dtf
 	if strings.Contains(expression[0].String(), "..") {
 		if len(expression) != 2 {
-			return nil, sql.ErrInvalidArgumentNumber.New(fmt.Sprintf("%v with .. or ...", dtf.Name()), 2, len(expression))
+			return nil, sql.ErrInvalidArgumentNumber.New(fmt.Sprintf("%v with .. or ...", newDtf.Name()), 2, len(expression))
 		}
-		dtf.dotCommitExpr = expression[0]
-		dtf.tableNameExpr = expression[1]
+		newDtf.dotCommitExpr = expression[0]
+		newDtf.tableNameExpr = expression[1]
 	} else {
 		if len(expression) != 3 {
-			return nil, sql.ErrInvalidArgumentNumber.New(dtf.Name(), 3, len(expression))
+			return nil, sql.ErrInvalidArgumentNumber.New(newDtf.Name(), 3, len(expression))
 		}
-		dtf.fromCommitExpr = expression[0]
-		dtf.toCommitExpr = expression[1]
-		dtf.tableNameExpr = expression[2]
+		newDtf.fromCommitExpr = expression[0]
+		newDtf.toCommitExpr = expression[1]
+		newDtf.tableNameExpr = expression[2]
 	}
 
-	fromCommitVal, toCommitVal, dotCommitVal, tableName, err := dtf.evaluateArguments()
+	fromCommitVal, toCommitVal, dotCommitVal, tableName, err := newDtf.evaluateArguments()
 	if err != nil {
 		return nil, err
 	}
 
-	err = dtf.generateSchema(dtf.ctx, fromCommitVal, toCommitVal, dotCommitVal, tableName)
+	err = newDtf.generateSchema(newDtf.ctx, fromCommitVal, toCommitVal, dotCommitVal, tableName)
 	if err != nil {
 		return nil, err
 	}
 
-	return dtf, nil
+	return &newDtf, nil
 }
 
 // Children implements the sql.Node interface
@@ -169,7 +169,7 @@ func (dtf *DiffTableFunction) RowIter(ctx *sql.Context, _ sql.Row) (sql.RowIter,
 	ddb := sqledb.DbData().Ddb
 	dp := dtables.NewDiffPartition(dtf.tableDelta.ToTable, dtf.tableDelta.FromTable, toCommitStr, fromCommitStr, dtf.toDate, dtf.fromDate, dtf.tableDelta.ToSch, dtf.tableDelta.FromSch)
 
-	return NewDiffTableFunctionRowIterForSinglePartition(*dp, ddb, dtf.joiner), nil
+	return dtables.NewDiffPartitionRowIter(*dp, ddb, dtf.joiner), nil
 }
 
 // findMatchingDelta returns the best matching table delta for the table name
@@ -207,16 +207,19 @@ func loadDetailsForRefs(ctx *sql.Context, fromRef, toRef, dotRef interface{}, db
 	}
 
 	sess := dsess.DSessFromSess(ctx.Session)
+	dbName := db.Name()
 
-	fromDetails, err := resolveRoot(ctx, sess, db.Name(), fromCommitStr)
+	fromRoot, fromCommitTime, fromHashStr, err := sess.ResolveRootForRef(ctx, dbName, fromCommitStr)
 	if err != nil {
 		return nil, nil, err
 	}
+	fromDetails := &refDetails{fromRoot, fromHashStr, fromCommitTime}
 
-	toDetails, err := resolveRoot(ctx, sess, db.Name(), toCommitStr)
+	toRoot, toCommitTime, toHashStr, err := sess.ResolveRootForRef(ctx, dbName, toCommitStr)
 	if err != nil {
 		return nil, nil, err
 	}
+	toDetails := &refDetails{toRoot, toHashStr, toCommitTime}
 
 	return fromDetails, toDetails, nil
 }
@@ -298,7 +301,7 @@ func interfaceToString(r interface{}) (string, error) {
 }
 
 func resolveRoot(ctx *sql.Context, sess *dsess.DoltSession, dbName, hashStr string) (*refDetails, error) {
-	root, commitTime, err := sess.ResolveRootForRef(ctx, dbName, hashStr)
+	root, commitTime, _, err := sess.ResolveRootForRef(ctx, dbName, hashStr)
 	if err != nil {
 		return nil, err
 	}
@@ -551,74 +554,3 @@ func (dtf *DiffTableFunction) String() string {
 func (dtf *DiffTableFunction) Name() string {
 	return "dolt_diff"
 }
-
-//------------------------------------
-// diffTableFunctionRowIter
-//------------------------------------
-
-var _ sql.RowIter = (*diffTableFunctionRowIter)(nil)
-
-type diffTableFunctionRowIter struct {
-	diffPartitions   *dtables.DiffPartitions
-	ddb              *doltdb.DoltDB
-	joiner           *rowconv.Joiner
-	currentPartition *sql.Partition
-	currentRowIter   *sql.RowIter
-}
-
-func NewDiffTableFunctionRowIter(partitions *dtables.DiffPartitions, ddb *doltdb.DoltDB, joiner *rowconv.Joiner) *diffTableFunctionRowIter {
-	return &diffTableFunctionRowIter{
-		diffPartitions: partitions,
-		ddb:            ddb,
-		joiner:         joiner,
-	}
-}
-
-func NewDiffTableFunctionRowIterForSinglePartition(partition sql.Partition, ddb *doltdb.DoltDB, joiner *rowconv.Joiner) *diffTableFunctionRowIter {
-	return &diffTableFunctionRowIter{
-		currentPartition: &partition,
-		ddb:              ddb,
-		joiner:           joiner,
-	}
-}
-
-func (itr *diffTableFunctionRowIter) Next(ctx *sql.Context) (sql.Row, error) {
-	for {
-		if itr.currentPartition == nil {
-			nextPartition, err := itr.diffPartitions.Next(ctx)
-			if err != nil {
-				return nil, err
-			}
-			itr.currentPartition = &nextPartition
-		}
-
-		if itr.currentRowIter == nil {
-			dp := (*itr.currentPartition).(dtables.DiffPartition)
-			rowIter, err := dp.GetRowIter(ctx, itr.ddb, itr.joiner, sql.IndexLookup{})
-			if err != nil {
-				return nil, err
-			}
-			itr.currentRowIter = &rowIter
-		}
-
-		row, err := (*itr.currentRowIter).Next(ctx)
-		if err == io.EOF {
-			itr.currentPartition = nil
-			itr.currentRowIter = nil
-
-			if itr.diffPartitions == nil {
-				return nil, err
-			}
-
-			continue
-		} else if err != nil {
-			return nil, err
-		} else {
-			return row, nil
-		}
-	}
-}
-
-func (itr *diffTableFunctionRowIter) Close(_ *sql.Context) error {
-	return nil
-}
