@@ -16,13 +16,9 @@ package index_test
 
 import (
 	"context"
-	"encoding/binary"
-	"encoding/hex"
 	"errors"
 	"fmt"
 	"io"
-	"math"
-	"math/rand"
 	"sort"
 	"strings"
 	"testing"
@@ -1411,10 +1407,11 @@ INSERT INTO types VALUES (1, 4, '2020-05-14 12:00:03', 1.1, 'd', 1.1, 'a,c', '00
 
 func NewTestSQLCtx(ctx context.Context) *sql.Context {
 	s := dsess.DefaultSession(dsess.EmptyDatabaseProvider())
+	s.SetCurrentDatabase("dolt")
 	sqlCtx := sql.NewContext(
 		ctx,
 		sql.WithSession(s),
-	).WithCurrentDB("dolt")
+	)
 
 	return sqlCtx
 }
@@ -1530,150 +1527,3 @@ func TestSplitNullsFromRange(t *testing.T) {
 		assert.Len(t, rs, 8)
 	})
 }
-
-func TestLexFloat(t *testing.T) {
-	t.Run("test edge case lex float values", func(t *testing.T) {
-		assert.Equal(t, uint64(0x0010000000000000), index.LexFloat(-math.MaxFloat64))
-		assert.Equal(t, uint64(0x7ffffffffffffffe), index.LexFloat(-math.SmallestNonzeroFloat64))
-		assert.Equal(t, uint64(0x8000000000000000), index.LexFloat(0.0))
-		assert.Equal(t, uint64(0x8000000000000001), index.LexFloat(math.SmallestNonzeroFloat64))
-		assert.Equal(t, uint64(0xffefffffffffffff), index.LexFloat(math.MaxFloat64))
-		assert.Equal(t, uint64(0xfff8000000000001), index.LexFloat(math.NaN()))
-		assert.Equal(t, uint64(0x0007fffffffffffe), index.LexFloat(-math.NaN()))
-		assert.Equal(t, uint64(0xfff0000000000000), index.LexFloat(math.Inf(1)))
-		assert.Equal(t, uint64(0x000fffffffffffff), index.LexFloat(math.Inf(-1)))
-	})
-
-	t.Run("test reverse lex float values", func(t *testing.T) {
-		assert.Equal(t, -math.MaxFloat64, index.UnLexFloat(0x0010000000000000))
-		assert.Equal(t, -math.SmallestNonzeroFloat64, index.UnLexFloat(0x7ffffffffffffffe))
-		assert.Equal(t, 0.0, index.UnLexFloat(0x8000000000000000))
-		assert.Equal(t, math.SmallestNonzeroFloat64, index.UnLexFloat(0x8000000000000001))
-		assert.Equal(t, math.MaxFloat64, index.UnLexFloat(0xffefffffffffffff))
-		assert.True(t, math.IsNaN(index.UnLexFloat(0xfff8000000000001)))
-		assert.True(t, math.IsNaN(index.UnLexFloat(0xfff7fffffffffffe)))
-		assert.True(t, math.IsInf(index.UnLexFloat(0xfff0000000000000), 1))
-		assert.True(t, math.IsInf(index.UnLexFloat(0x000fffffffffffff), -1))
-	})
-
-	t.Run("test sort lex float", func(t *testing.T) {
-		sortedFloats := []float64{
-			-math.MaxFloat64,
-			-1.0,
-			-0.5,
-			-0.123456789,
-			-math.SmallestNonzeroFloat64,
-			-0.0,
-			0.0,
-			math.SmallestNonzeroFloat64,
-			0.5,
-			0.987654321,
-			1.0,
-			math.MaxFloat64,
-		}
-
-		randFloats := append([]float64{}, sortedFloats...)
-		rand.Shuffle(len(randFloats), func(i, j int) {
-			randFloats[i], randFloats[j] = randFloats[j], randFloats[i]
-		})
-		sort.Slice(randFloats, func(i, j int) bool {
-			l1 := index.LexFloat(randFloats[i])
-			l2 := index.LexFloat(randFloats[j])
-			return l1 < l2
-		})
-		assert.Equal(t, sortedFloats, randFloats)
-	})
-}
-
-func TestZValues(t *testing.T) {
-	tests := []struct {
-		p types.Point
-		e string
-	}{
-		{
-			p: types.Point{X: -5000, Y: -5000},
-			e: "0fff30f03f3fffffffffffffffffffff",
-		},
-		{
-			p: types.Point{X: -1, Y: -1},
-			e: "300000ffffffffffffffffffffffffff",
-		},
-		{
-			p: types.Point{X: -1, Y: 0},
-			e: "90000055555555555555555555555555",
-		},
-		{
-			p: types.Point{X: -1, Y: 1},
-			e: "9aaaaa55555555555555555555555555",
-		},
-		{
-			p: types.Point{X: 0, Y: -1},
-			e: "600000aaaaaaaaaaaaaaaaaaaaaaaaaa",
-		},
-		{
-			p: types.Point{X: 1, Y: -1},
-			e: "655555aaaaaaaaaaaaaaaaaaaaaaaaaa",
-		},
-		{
-			p: types.Point{X: 0, Y: 0},
-			e: "c0000000000000000000000000000000",
-		},
-		{
-			p: types.Point{X: 1, Y: 0},
-			e: "c5555500000000000000000000000000",
-		},
-		{
-			p: types.Point{X: 0, Y: 1},
-			e: "caaaaa00000000000000000000000000",
-		},
-		{
-			p: types.Point{X: 1, Y: 1},
-			e: "cfffff00000000000000000000000000",
-		},
-		{
-			p: types.Point{X: 2, Y: 2},
-			e: "f0000000000000000000000000000000",
-		},
-		{
-			p: types.Point{X: 50000, Y: 50000},
-			e: "f000fcc03ccc00000000000000000000",
-		},
-	}
-
-	t.Run("test z-values", func(t *testing.T) {
-		for _, test := range tests {
-			z := index.ZValue(test.p)
-			assert.Equal(t, test.e, fmt.Sprintf("%016x%016x", z[0], z[1]))
-		}
-	})
-
-	t.Run("test un-z-values", func(t *testing.T) {
-		for _, test := range tests {
-			v, _ := hex.DecodeString(test.e)
-			z := [2]uint64{}
-			z[0] = binary.BigEndian.Uint64(v[:8])
-			z[1] = binary.BigEndian.Uint64(v[8:])
-			assert.Equal(t, test.p, index.UnZValue(z))
-		}
-	})
-
-	t.Run("test sorting points by z-value", func(t *testing.T) {
-		sortedPoints := []types.Point{
-			{X: -5000, Y: -5000},
-			{X: -1, Y: -1},
-			{X: 1, Y: -1},
-			{X: -1, Y: 0},
-			{X: -1, Y: 1},
-			{X: 0, Y: 0},
-			{X: 1, Y: 0},
-			{X: 1, Y: 1},
-			{X: 2, Y: 2},
-			{X: 100, Y: 100},
-		}
-		randPoints := append([]types.Point{}, sortedPoints...)
-		rand.Shuffle(len(randPoints), func(i, j int) {
-			randPoints[i], randPoints[j] = randPoints[j], randPoints[i]
-		})
-		assert.Equal(t, sortedPoints, index.ZSort(randPoints))
-	})
-}
