@@ -243,6 +243,7 @@ type fmtIndex struct {
 
 	cols      []schema.Column
 	unique    bool
+	spatial   bool
 	generated bool
 	comment   string
 }
@@ -281,6 +282,11 @@ func (idx fmtIndex) IsUnique() bool {
 	return idx.unique
 }
 
+// IsSpatial implements sql.Index
+func (idx fmtIndex) IsSpatial() bool {
+	return idx.spatial
+}
+
 // Comment implements sql.Index
 func (idx fmtIndex) Comment() string {
 	return idx.comment
