@@ -62,6 +62,11 @@ type Database interface {
 
 	GetDatasetsByRootHash(ctx context.Context, rootHash hash.Hash) (DatasetsMap, error)
 
+	// BuildNewCommit creates a new Commit struct for the provided dataset,
+	// but does not modify the dataset. This allows the commit to be inspected
+	// if necessary before any update is performed.
+	BuildNewCommit(ctx context.Context, ds Dataset, v types.Value, opts CommitOptions) (*Commit, error)
+
 	// Commit updates the Commit that ds.ID() in this database points at. All
 	// Values that have been written to this Database are guaranteed to be
 	// persistent after Commit() returns successfully.
@@ -76,6 +81,10 @@ type Database interface {
 	// an 'ErrMergeNeeded' error.
 	Commit(ctx context.Context, ds Dataset, v types.Value, opts CommitOptions) (Dataset, error)
 
+	// WriteCommit has the same behavior as Commit but accepts an already-constructed Commit
+	// instead of constructing one from a Value and CommitOptions
+	WriteCommit(ctx context.Context, ds Dataset, commit *Commit) (Dataset, error)
+
 	// Tag stores an immutable reference to a Commit. It takes a Hash to
 	// the Commit and a Dataset whose head must be nil (ie a newly created
 	// Dataset).  The new Tag struct is constructed pointing at
@@ -166,7 +175,7 @@ type GarbageCollector interface {
 
 	// GC traverses the database starting at the Root and removes
 	// all unreferenced data from persistent storage.
-	GC(ctx context.Context, oldGenRefs, newGenRefs hash.HashSet) error
+	GC(ctx context.Context, oldGenRefs, newGenRefs hash.HashSet, safepointF func() error) error
 }
 
 // CanUsePuller returns true if a datas.Puller can be used to pull data from one Database into another.  Not all
