@@ -125,7 +125,7 @@ func (m *fakeDDB) PutItemWithContext(ctx aws.Context, input *dynamodb.PutItemInp
 
 	assert.NotNil(m.t, input.Item[versAttr], "%s should have been present", versAttr)
 	assert.NotNil(m.t, input.Item[versAttr].S, "nbsVers should have been a String: %+v", input.Item[versAttr])
-	assert.Equal(m.t, constants.NomsVersion, *input.Item[versAttr].S)
+	assert.Equal(m.t, constants.FormatLD1String, *input.Item[versAttr].S)
 
 	assert.NotNil(m.t, input.Item[lockAttr], "%s should have been present", lockAttr)
 	assert.NotNil(m.t, input.Item[lockAttr].B, "lock should have been a blob: %+v", input.Item[lockAttr])
@@ -156,7 +156,7 @@ func (m *fakeDDB) PutItemWithContext(ctx aws.Context, input *dynamodb.PutItemInp
 		return nil, mockAWSError("ConditionalCheckFailedException")
 	}
 
-	m.putRecord(key, lock, root, constants.NomsVersion, specs, apps)
+	m.putRecord(key, lock, root, constants.FormatLD1String, specs, apps)
 
 	atomic.AddInt64(&m.numPuts, 1)
 	return &dynamodb.PutItemOutput{}, nil
