@@ -213,9 +213,7 @@ func (fm fileManifest) UpdateGCGen(ctx context.Context, lastLock addr, newConten
 	checker := func(upstream, contents manifestContents) error {
 		if contents.gcGen == upstream.gcGen {
 			return errors.New("UpdateGCGen() must update the garbage collection generation")
-		}
-
-		if contents.root != upstream.root {
+		} else if contents.root != upstream.root {
 			return errors.New("UpdateGCGen() cannot update the root")
 		}
 		return nil
