@@ -129,26 +129,39 @@ func (j *chunkJournal) bootstrapJournalWriter(ctx context.Context) (err error) {
 		return err
 	}
 
-	var contents manifestContents
-	ok, contents, err = j.backing.ParseIfExists(ctx, &Stats{}, nil)
+	mc, err := trueUpBackingManifest(ctx, root, j.backing)
 	if err != nil {
 		return err
 	}
-
-	if ok {
-		// the journal file is the source of truth for the root hash, true-up persisted manifest
-		contents.root = root
-		contents, err = j.backing.Update(ctx, contents.lock, contents, &Stats{}, nil)
-		if err != nil {
-			return err
-		}
-	} else {
-		return fmt.Errorf("manifest not found when opening chunk journal")
-	}
-	j.contents = contents
+	j.contents = mc
 	return
 }
 
+// the journal file is the source of truth for the root hash, true-up persisted manifest
+func trueUpBackingManifest(ctx context.Context, root hash.Hash, backing manifest) (manifestContents, error) {
+	ok, mc, err := backing.ParseIfExists(ctx, &Stats{}, nil)
+	if err != nil {
+		return manifestContents{}, err
+	} else if !ok {
+		return manifestContents{}, fmt.Errorf("manifest not found when opening chunk journal")
+	}
+
+	prev := mc.lock
+	next := generateLockHash(root, mc.specs, mc.appendix)
+	mc.lock = next
+	mc.root = root
+
+	mc, err = backing.Update(ctx, prev, mc, &Stats{}, nil)
+	if err != nil {
+		return manifestContents{}, err
+	} else if mc.lock != next {
+		return manifestContents{}, errOptimisticLockFailedTables
+	} else if mc.root != root {
+		return manifestContents{}, errOptimisticLockFailedRoot
+	}
+	return mc, nil
+}
+
 // Persist implements tablePersister.
 func (j *chunkJournal) Persist(ctx context.Context, mt *memTable, haver chunkReader, stats *Stats) (chunkSource, error) {
 	if err := j.maybeInit(ctx); err != nil {
@@ -199,6 +212,16 @@ func (j *chunkJournal) Exists(ctx context.Context, name addr, chunkCount uint32,
 
 // PruneTableFiles implements tablePersister.
 func (j *chunkJournal) PruneTableFiles(ctx context.Context, keeper func() []addr, mtime time.Time) error {
+	// sanity check that we're not deleting the journal
+	var keepJournal bool
+	for _, a := range keeper() {
+		if a == journalAddr {
+			keepJournal = true
+		}
+	}
+	if j.wr != nil && !keepJournal {
+		return errors.New("cannot drop chunk journal through tablePersister.PruneTableFiles()")
+	}
 	return j.persister.PruneTableFiles(ctx, keeper, mtime)
 }
 
@@ -218,7 +241,7 @@ func (j *chunkJournal) Name() string {
 // Update implements manifest.
 func (j *chunkJournal) Update(ctx context.Context, lastLock addr, next manifestContents, stats *Stats, writeHook func() error) (manifestContents, error) {
 	if j.wr == nil {
-		// pass the update to |j.backing| if the journals is not initialized
+		// pass the update to |j.backing| if the journal is not initialized
 		return j.backing.Update(ctx, lastLock, next, stats, writeHook)
 	}
 
@@ -236,18 +259,9 @@ func (j *chunkJournal) Update(ctx context.Context, lastLock addr, next manifestC
 
 	// if |next| has a different table file set, flush to |j.backing|
 	if !equalSpecs(j.contents.specs, next.specs) {
-		_, mc, err := j.backing.ParseIfExists(ctx, stats, nil)
-		if err != nil {
+		if err := j.flushToBackingManifest(ctx, next, stats); err != nil {
 			return manifestContents{}, err
 		}
-		lastLock = mc.lock
-
-		mc, err = j.backing.Update(ctx, lastLock, next, stats, nil)
-		if err != nil {
-			return manifestContents{}, err
-		} else if mc.lock != next.lock {
-			return manifestContents{}, errOptimisticLockFailedTables
-		}
 	}
 
 	if err := j.wr.commitRootHash(next.root); err != nil {
@@ -262,19 +276,70 @@ func (j *chunkJournal) Update(ctx context.Context, lastLock addr, next manifestC
 func (j *chunkJournal) UpdateGCGen(ctx context.Context, lastLock addr, next manifestContents, stats *Stats, writeHook func() error) (manifestContents, error) {
 	updater, ok := j.backing.(manifestGCGenUpdater)
 	if !ok {
-		err := fmt.Errorf("backing manifest (%s) does not support garbage collection", j.backing.Name())
+		return manifestContents{}, fmt.Errorf("manifest (%s) does not support garbage collection", j.backing.Name())
+	}
+
+	if j.wr == nil {
+		// pass the update to |j.backing| if the journal is not initialized
+		return updater.UpdateGCGen(ctx, lastLock, next, stats, writeHook)
+	}
+
+	if j.contents.lock != lastLock {
+		return j.contents, nil // |next| is stale
+	}
+
+	// UpdateGCGen below cannot update the root hash, only the GC generation
+	// flush |j.contents| with the latest root hash here
+	if err := j.flushToBackingManifest(ctx, j.contents, stats); err != nil {
 		return manifestContents{}, err
 	}
 
-	latest, err := updater.UpdateGCGen(ctx, lastLock, next, stats, writeHook)
+	latest, err := updater.UpdateGCGen(ctx, j.contents.lock, next, stats, writeHook)
 	if err != nil {
 		return manifestContents{}, err
 	} else if latest.root == next.root {
 		j.contents = next // success
 	}
+
+	// if we're landing a new manifest without the chunk journal
+	// then physically delete the journal here and cleanup |j.wr|
+	if !containsJournalSpec(latest.specs) {
+		if err = j.dropJournalWriter(ctx); err != nil {
+			return manifestContents{}, err
+		}
+	}
 	return latest, nil
 }
 
+// flushToBackingManifest attempts to update the backing file manifest with |next|. This is necessary
+// when making manifest updates other than root hash updates (adding new table files, updating GC gen, etc).
+func (j *chunkJournal) flushToBackingManifest(ctx context.Context, next manifestContents, stats *Stats) error {
+	_, prev, err := j.backing.ParseIfExists(ctx, stats, nil)
+	if err != nil {
+		return err
+	}
+	var mc manifestContents
+	mc, err = j.backing.Update(ctx, prev.lock, next, stats, nil)
+	if err != nil {
+		return err
+	} else if mc.lock != next.lock {
+		return errOptimisticLockFailedTables
+	}
+	return nil
+}
+
+func (j *chunkJournal) dropJournalWriter(ctx context.Context) error {
+	curr := j.wr
+	if j.wr == nil {
+		return nil
+	}
+	j.wr = nil
+	if err := curr.Close(); err != nil {
+		return err
+	}
+	return deleteJournalAndIndexFiles(ctx, curr.path)
+}
+
 // ParseIfExists implements manifest.
 func (j *chunkJournal) ParseIfExists(ctx context.Context, stats *Stats, readHook func() error) (ok bool, mc manifestContents, err error) {
 	if j.wr == nil {
@@ -341,3 +406,12 @@ func (c journalConjoiner) chooseConjoinees(upstream []tableSpec) (conjoinees, ke
 	keepers = append(keepers, stash)
 	return
 }
+
+func containsJournalSpec(specs []tableSpec) (ok bool) {
+	for _, spec := range specs {
+		if spec.name == journalAddr {
+			ok = true
+		}
+	}
+	return
+}
