@@ -95,7 +95,8 @@ type NomsBlockStore struct {
 	upstream manifestContents
 
 	cond         *sync.Cond
-	gcInProgress atomic.Bool
+	gcInProgress bool
+	keeperFunc   func(hash.Hash) bool
 
 	mtSize   uint64
 	putCount uint64
@@ -161,10 +162,39 @@ func (nbs *NomsBlockStore) GetChunkLocations(hashes hash.HashSet) (map[hash.Hash
 	return ranges, nil
 }
 
+func (nbs *NomsBlockStore) conjoinIfRequired(ctx context.Context) (bool, error) {
+	if nbs.c.conjoinRequired(nbs.tables) {
+		newUpstream, cleanup, err := conjoin(ctx, nbs.c, nbs.upstream, nbs.mm, nbs.p, nbs.stats)
+		if err != nil {
+			return false, err
+		}
+
+		newTables, err := nbs.tables.rebase(ctx, newUpstream.specs, nbs.stats)
+		if err != nil {
+			return false, err
+		}
+
+		nbs.upstream = newUpstream
+		oldTables := nbs.tables
+		nbs.tables = newTables
+		err = oldTables.close()
+		if err != nil {
+			return true, err
+		}
+		cleanup()
+		return true, nil
+	} else {
+		return false, nil
+	}
+}
+
 func (nbs *NomsBlockStore) UpdateManifest(ctx context.Context, updates map[hash.Hash]uint32) (mi ManifestInfo, err error) {
 	nbs.mu.Lock()
 	defer nbs.mu.Unlock()
-	nbs.waitForGC()
+	err = nbs.waitForGC(ctx)
+	if err != nil {
+		return
+	}
 
 	nbs.checkAllManifestUpdatesExist(ctx, updates)
 
@@ -177,6 +207,11 @@ func (nbs *NomsBlockStore) UpdateManifest(ctx context.Context, updates map[hash.
 		}
 	}()
 
+	_, err = nbs.conjoinIfRequired(ctx)
+	if err != nil {
+		return manifestContents{}, err
+	}
+
 	var updatedContents manifestContents
 	for {
 		ok, contents, _, ferr := nbs.mm.Fetch(ctx, nbs.stats)
@@ -243,7 +278,10 @@ func (nbs *NomsBlockStore) UpdateManifest(ctx context.Context, updates map[hash.
 func (nbs *NomsBlockStore) UpdateManifestWithAppendix(ctx context.Context, updates map[hash.Hash]uint32, option ManifestAppendixOption) (mi ManifestInfo, err error) {
 	nbs.mu.Lock()
 	defer nbs.mu.Unlock()
-	nbs.waitForGC()
+	err = nbs.waitForGC(ctx)
+	if err != nil {
+		return
+	}
 
 	nbs.checkAllManifestUpdatesExist(ctx, updates)
 
@@ -256,6 +294,11 @@ func (nbs *NomsBlockStore) UpdateManifestWithAppendix(ctx context.Context, updat
 		}
 	}()
 
+	_, err = nbs.conjoinIfRequired(ctx)
+	if err != nil {
+		return manifestContents{}, err
+	}
+
 	var updatedContents manifestContents
 	for {
 		ok, contents, _, ferr := nbs.mm.Fetch(ctx, nbs.stats)
@@ -391,7 +434,10 @@ func fromManifestAppendixOptionNewContents(upstream manifestContents, appendixSp
 func OverwriteStoreManifest(ctx context.Context, store *NomsBlockStore, root hash.Hash, tableFiles map[hash.Hash]uint32, appendixTableFiles map[hash.Hash]uint32) (err error) {
 	store.mu.Lock()
 	defer store.mu.Unlock()
-	store.waitForGC()
+	err = store.waitForGC(ctx)
+	if err != nil {
+		return
+	}
 
 	contents := manifestContents{
 		root:    root,
@@ -603,10 +649,20 @@ func (nbs *NomsBlockStore) WithoutConjoiner() *NomsBlockStore {
 }
 
 // Wait for GC to complete to continue with writes
-func (nbs *NomsBlockStore) waitForGC() {
-	for nbs.gcInProgress.Load() {
+func (nbs *NomsBlockStore) waitForGC(ctx context.Context) error {
+	stop := make(chan struct{})
+	defer close(stop)
+	go func() {
+		select {
+		case <-ctx.Done():
+			nbs.cond.Broadcast()
+		case <-stop:
+		}
+	}()
+	for nbs.gcInProgress && ctx.Err() == nil {
 		nbs.cond.Wait()
 	}
+	return ctx.Err()
 }
 
 func (nbs *NomsBlockStore) Put(ctx context.Context, c chunks.Chunk, getAddrs chunks.GetAddrsCb) error {
@@ -639,28 +695,43 @@ func (nbs *NomsBlockStore) addChunk(ctx context.Context, ch chunks.Chunk, addrs
 	}
 	nbs.mu.Lock()
 	defer nbs.mu.Unlock()
-	nbs.waitForGC()
-	if nbs.mt == nil {
-		nbs.mt = newMemTable(nbs.mtSize)
-	}
-	a := addr(ch.Hash())
 
-	addChunkRes := nbs.mt.addChunk(a, ch.Data())
-	if addChunkRes == chunkNotAdded {
-		ts, err := nbs.tables.append(ctx, nbs.mt, checker, nbs.stats)
-		if err != nil {
-			if errors.Is(err, ErrDanglingRef) {
-				nbs.mt = nil
-			}
-			return false, err
+	retry := true
+	var addChunkRes addChunkResult
+	for retry {
+		retry = false
+		if nbs.mt == nil {
+			nbs.mt = newMemTable(nbs.mtSize)
 		}
-		nbs.tables = ts
-		nbs.mt = newMemTable(nbs.mtSize)
+		a := addr(ch.Hash())
+
 		addChunkRes = nbs.mt.addChunk(a, ch.Data())
+		if addChunkRes == chunkNotAdded {
+			ts, err := nbs.tables.append(ctx, nbs.mt, checker, nbs.stats)
+			if err != nil {
+				if errors.Is(err, ErrDanglingRef) {
+					nbs.mt = nil
+				}
+				return false, err
+			}
+			nbs.tables = ts
+			nbs.mt = newMemTable(nbs.mtSize)
+			addChunkRes = nbs.mt.addChunk(a, ch.Data())
+		}
+		if addChunkRes == chunkAdded || addChunkRes == chunkExists {
+			if nbs.keeperFunc != nil && nbs.keeperFunc(ch.Hash()) {
+				retry = true
+				if err := nbs.waitForGC(ctx); err != nil {
+					return false, err
+				}
+				continue
+			}
+		}
+		if addChunkRes == chunkAdded {
+			nbs.mt.addChildRefs(addrs)
+		}
 	}
-	if addChunkRes == chunkAdded {
-		nbs.mt.addChildRefs(addrs)
-	}
+
 	return addChunkRes == chunkAdded || addChunkRes == chunkExists, nil
 }
 
@@ -668,8 +739,21 @@ func (nbs *NomsBlockStore) addChunk(ctx context.Context, ch chunks.Chunk, addrs
 type refCheck func(reqs []hasRecord) (hash.HashSet, error)
 
 func (nbs *NomsBlockStore) errorIfDangling(root hash.Hash, checker refCheck) error {
+	if !root.IsEmpty() {
+		var hr [1]hasRecord
+		a := addr(root)
+		hr[0].a = &a
+		hr[0].prefix = a.Prefix()
+		absent, err := checker(hr[:])
+		if err != nil {
+			return err
+		} else if absent.Size() > 0 {
+			return fmt.Errorf("%w: found dangling references to %s", ErrDanglingRef, absent.String())
+		}
+	}
+
 	if nbs.mt == nil || nbs.mt.pendingRefs == nil {
-		return nil // no refs to check
+		return nil // no pending refs to check
 	}
 
 	sort.Sort(hasRecordByPrefix(nbs.mt.pendingRefs))
@@ -680,17 +764,6 @@ func (nbs *NomsBlockStore) errorIfDangling(root hash.Hash, checker refCheck) err
 		return fmt.Errorf("%w: found dangling references to %s", ErrDanglingRef, absent.String())
 	}
 
-	var hr [1]hasRecord
-	a := addr(root)
-	hr[0].a = &a
-	hr[0].prefix = a.Prefix()
-	absent, err = checker(hr[:])
-	if err != nil {
-		return err
-	} else if absent.Size() > 0 {
-		return fmt.Errorf("%w: found dangling references to %s", ErrDanglingRef, absent.String())
-	}
-
 	return nil
 }
 
@@ -956,7 +1029,10 @@ func toHasRecords(hashes hash.HashSet) []hasRecord {
 func (nbs *NomsBlockStore) Rebase(ctx context.Context) error {
 	nbs.mu.Lock()
 	defer nbs.mu.Unlock()
-	nbs.waitForGC()
+	return nbs.rebase(ctx)
+}
+
+func (nbs *NomsBlockStore) rebase(ctx context.Context) error {
 	exists, contents, _, err := nbs.mm.Fetch(ctx, nbs.stats)
 	if err != nil {
 		return err
@@ -1000,21 +1076,27 @@ func (nbs *NomsBlockStore) commit(ctx context.Context, current, last hash.Hash,
 	defer nbs.stats.CommitLatency.SampleTimeSince(t1)
 
 	nbs.mu.Lock()
-	nbs.waitForGC()
+	defer nbs.mu.Unlock()
+
+	if nbs.keeperFunc != nil {
+		if nbs.keeperFunc(current) {
+			err = nbs.waitForGC(ctx)
+			if err != nil {
+				return false, err
+			}
+		}
+	}
 
 	anyPossiblyNovelChunks := nbs.mt != nil || len(nbs.tables.novel) > 0
 
 	if !anyPossiblyNovelChunks && current == last {
-		nbs.mu.Unlock()
-		err := nbs.Rebase(ctx)
+		err := nbs.rebase(ctx)
 		if err != nil {
 			return false, err
 		}
 		return true, nil
 	}
 
-	defer nbs.mu.Unlock()
-
 	// check for dangling references in |nbs.mt|
 	if err = nbs.errorIfDangling(current, checker); err != nil {
 		if errors.Is(err, ErrDanglingRef) {
@@ -1126,25 +1208,11 @@ func (nbs *NomsBlockStore) updateManifest(ctx context.Context, current, last has
 		}
 	}
 
-	if nbs.c.conjoinRequired(nbs.tables) {
-		newUpstream, cleanup, err := conjoin(ctx, nbs.c, nbs.upstream, nbs.mm, nbs.p, nbs.stats)
-		if err != nil {
-			return err
-		}
-
-		newTables, err := nbs.tables.rebase(ctx, newUpstream.specs, nbs.stats)
-		if err != nil {
-			return err
-		}
-
-		nbs.upstream = newUpstream
-		oldTables := nbs.tables
-		nbs.tables = newTables
-		err = oldTables.close()
-		if err != nil {
-			return err
-		}
-		cleanup()
+	didConjoin, err := nbs.conjoinIfRequired(ctx)
+	if err != nil {
+		return err
+	}
+	if didConjoin {
 		return errOptimisticLockFailedTables
 	}
 
@@ -1192,7 +1260,7 @@ func (nbs *NomsBlockStore) updateManifest(ctx context.Context, current, last has
 	newTables, err := nbs.tables.flatten(ctx)
 
 	if err != nil {
-		return nil
+		return err
 	}
 
 	nbs.upstream = newContents
@@ -1430,26 +1498,30 @@ func (nbs *NomsBlockStore) pruneTableFiles(ctx context.Context, checker refCheck
 	}, mtime)
 }
 
-func (nbs *NomsBlockStore) setGCInProgress(inProgress bool) bool {
+func (nbs *NomsBlockStore) BeginGC(keeper func(hash.Hash) bool) error {
 	nbs.cond.L.Lock()
 	defer nbs.cond.L.Unlock()
-
-	swapped := nbs.gcInProgress.CompareAndSwap(!inProgress, inProgress)
-	if swapped {
-		nbs.cond.Broadcast()
-		return true
-	}
-
-	return false
-}
-
-func (nbs *NomsBlockStore) MarkAndSweepChunks(ctx context.Context, last hash.Hash, keepChunks <-chan []hash.Hash, dest chunks.ChunkStore) error {
-	swapped := nbs.setGCInProgress(true)
-	if !swapped {
+	if nbs.gcInProgress {
 		return errors.New("gc already in progress")
 	}
-	defer nbs.setGCInProgress(false)
+	nbs.gcInProgress = true
+	nbs.keeperFunc = keeper
+	nbs.cond.Broadcast()
+	return nil
+}
 
+func (nbs *NomsBlockStore) EndGC() {
+	nbs.cond.L.Lock()
+	defer nbs.cond.L.Unlock()
+	if !nbs.gcInProgress {
+		panic("EndGC called when gc was not in progress")
+	}
+	nbs.gcInProgress = false
+	nbs.keeperFunc = nil
+	nbs.cond.Broadcast()
+}
+
+func (nbs *NomsBlockStore) MarkAndSweepChunks(ctx context.Context, hashes <-chan []hash.Hash, dest chunks.ChunkStore) error {
 	ops := nbs.SupportedOperations()
 	if !ops.CanGC || !ops.CanPrune {
 		return chunks.ErrUnsupportedOperation
@@ -1459,12 +1531,8 @@ func (nbs *NomsBlockStore) MarkAndSweepChunks(ctx context.Context, last hash.Has
 		nbs.mu.RLock()
 		defer nbs.mu.RUnlock()
 
-		if nbs.upstream.root != last {
-			return errLastRootMismatch
-		}
-
 		// check to see if the specs have changed since last gc. If they haven't bail early.
-		gcGenCheck := generateLockHash(last, nbs.upstream.specs, nbs.upstream.appendix)
+		gcGenCheck := generateLockHash(nbs.upstream.root, nbs.upstream.specs, nbs.upstream.appendix)
 		if nbs.upstream.gcGen == gcGenCheck {
 			return chunks.ErrNothingToCollect
 		}
@@ -1486,7 +1554,7 @@ func (nbs *NomsBlockStore) MarkAndSweepChunks(ctx context.Context, last hash.Has
 		}
 	}
 
-	specs, err := nbs.copyMarkedChunks(ctx, keepChunks, destNBS)
+	specs, err := nbs.copyMarkedChunks(ctx, hashes, destNBS)
 	if err != nil {
 		return err
 	}
@@ -1498,12 +1566,7 @@ func (nbs *NomsBlockStore) MarkAndSweepChunks(ctx context.Context, last hash.Has
 		return nbs.swapTables(ctx, specs)
 	} else {
 		fileIdToNumChunks := tableSpecsToMap(specs)
-		err = destNBS.AddTableFilesToManifest(ctx, fileIdToNumChunks)
-
-		if err != nil {
-			return err
-		}
-		return nil
+		return destNBS.AddTableFilesToManifest(ctx, fileIdToNumChunks)
 	}
 }
 
@@ -1518,6 +1581,8 @@ func (nbs *NomsBlockStore) copyMarkedChunks(ctx context.Context, keepChunks <-ch
 		return nil, err
 	}
 
+	// TODO: We should clean up gcc on error.
+
 LOOP:
 	for {
 		select {
@@ -1528,12 +1593,14 @@ LOOP:
 			var addErr error
 			mu := new(sync.Mutex)
 			hashset := hash.NewHashSet(hs...)
+			found := 0
 			err := nbs.GetManyCompressed(ctx, hashset, func(ctx context.Context, c CompressedChunk) {
 				mu.Lock()
 				defer mu.Unlock()
 				if addErr != nil {
 					return
 				}
+				found += 1
 				addErr = gcc.addChunk(ctx, c)
 			})
 			if err != nil {
@@ -1542,6 +1609,9 @@ LOOP:
 			if addErr != nil {
 				return nil, addErr
 			}
+			if found != len(hashset) {
+				return nil, fmt.Errorf("dangling references requested during GC. GC not successful. %v", hashset)
+			}
 		case <-ctx.Done():
 			return nil, ctx.Err()
 		}
@@ -1549,23 +1619,6 @@ LOOP:
 	return gcc.copyTablesToDir(ctx, tfp)
 }
 
-// todo: what's the optimal table size to copy to?
-func (nbs *NomsBlockStore) gcTableSize() (uint64, error) {
-	total, err := nbs.tables.physicalLen()
-
-	if err != nil {
-		return 0, err
-	}
-
-	avgTableSize := total / uint64(nbs.tables.Size()+1)
-
-	// max(avgTableSize, defaultMemTableSize)
-	if avgTableSize > nbs.mtSize {
-		return avgTableSize, nil
-	}
-	return nbs.mtSize, nil
-}
-
 func (nbs *NomsBlockStore) swapTables(ctx context.Context, specs []tableSpec) (err error) {
 	nbs.mu.Lock()
 	defer nbs.mu.Unlock()
@@ -1587,7 +1640,7 @@ func (nbs *NomsBlockStore) swapTables(ctx context.Context, specs []tableSpec) (e
 		specs:   specs,
 	}
 
-	// nothing has changed. Bail early
+	// Nothing has changed. Bail early.
 	if newContents.gcGen == nbs.upstream.gcGen {
 		return nil
 	}
@@ -1608,7 +1661,30 @@ func (nbs *NomsBlockStore) swapTables(ctx context.Context, specs []tableSpec) (e
 	}
 	oldTables := nbs.tables
 	nbs.tables, nbs.upstream = ts, upstream
-	return oldTables.close()
+	err = oldTables.close()
+	if err != nil {
+		return err
+	}
+
+	// When this is called, we are at a safepoint in the GC process.
+	// We clear novel and the memtable, which are not coming with us
+	// into the new store.
+	oldNovel := nbs.tables.novel
+	nbs.tables.novel = make(chunkSourceSet)
+	for _, css := range oldNovel {
+		err = css.close()
+		if err != nil {
+			return err
+		}
+	}
+	if nbs.mt != nil {
+		var thrown []string
+		for a := range nbs.mt.chunks {
+			thrown = append(thrown, a.String())
+		}
+	}
+	nbs.mt = nil
+	return nil
 }
 
 // SetRootChunk changes the root chunk hash from the previous value to the new root.
@@ -1619,7 +1695,10 @@ func (nbs *NomsBlockStore) SetRootChunk(ctx context.Context, root, previous hash
 func (nbs *NomsBlockStore) setRootChunk(ctx context.Context, root, previous hash.Hash, checker refCheck) error {
 	nbs.mu.Lock()
 	defer nbs.mu.Unlock()
-	nbs.waitForGC()
+	err := nbs.waitForGC(ctx)
+	if err != nil {
+		return err
+	}
 	for {
 		err := nbs.updateManifest(ctx, root, previous, checker)
 
