@@ -108,11 +108,7 @@ func (c CommitClosure) IsEmpty() bool {
 
 func (c CommitClosure) ContainsKey(ctx context.Context, h hash.Hash, height uint64) (bool, error) {
 	k := NewCommitClosureKey(c.closure.NodeStore.Pool(), height, h)
-	cur, err := tree.NewCursorAtKey(ctx, c.closure.NodeStore, c.closure.Root, k, c.closure.Order)
-	if err != nil {
-		return false, err
-	}
-	return cur.Valid(), nil
+	return c.closure.Has(ctx, k)
 }
 
 func DecodeCommitClosureKey(key []byte) (height uint64, addr hash.Hash) {
