@@ -118,29 +118,10 @@ func DiffMaps(ctx context.Context, from, to Map, cb tree.DiffFn) error {
 // RangeDiffMaps returns diffs within a Range. See Range for which diffs are
 // returned.
 func RangeDiffMaps(ctx context.Context, from, to Map, rng Range, cb tree.DiffFn) error {
-	fns, tns := from.tuples.NodeStore, to.tuples.NodeStore
-
-	fromStart, err := tree.NewCursorFromSearchFn(ctx, fns, from.tuples.Root, rangeStartSearchFn(rng))
-	if err != nil {
-		return err
-	}
-	toStart, err := tree.NewCursorFromSearchFn(ctx, tns, to.tuples.Root, rangeStartSearchFn(rng))
-	if err != nil {
-		return err
-	}
-
-	fromStop, err := tree.NewCursorFromSearchFn(ctx, fns, from.tuples.Root, rangeStopSearchFn(rng))
-	if err != nil {
-		return err
-	}
-	toStop, err := tree.NewCursorFromSearchFn(ctx, tns, to.tuples.Root, rangeStopSearchFn(rng))
-	if err != nil {
-		return err
-	}
-
 	differ, err := tree.DifferFromCursors[val.Tuple, val.TupleDesc](
-		fromStart, toStart,
-		fromStop, toStop,
+		ctx, from.tuples.Root, to.tuples.Root,
+		rangeStartSearchFn(rng), rangeStopSearchFn(rng),
+		from.NodeStore(), to.NodeStore(),
 		from.tuples.Order,
 	)
 	if err != nil {
@@ -214,6 +195,14 @@ func (m Map) Tuples() tree.StaticMap[val.Tuple, val.Tuple, val.TupleDesc] {
 	return m.tuples
 }
 
+func (m Map) ValDesc() val.TupleDesc {
+	return m.valDesc
+}
+
+func (m Map) KeyDesc() val.TupleDesc {
+	return m.keyDesc
+}
+
 // Mutate makes a MutableMap from a Map.
 func (m Map) Mutate() *MutableMap {
 	return newMutableMap(m)
@@ -287,12 +276,20 @@ func (m Map) FetchOrdinalRange(ctx context.Context, start, stop uint64) (MapIter
 	return m.tuples.FetchOrdinalRange(ctx, start, stop)
 }
 
+// HasPrefix returns true if the Map contains any key matching |preKey|.
+func (m Map) HasPrefix(ctx context.Context, preKey val.Tuple, preDesc val.TupleDesc) (bool, error) {
+	// todo(andy): we should compute our own |prefixDesc| here, but
+	//  we can't do that efficiently with the current TupleDesc.
+	if preKey.Count() < preDesc.Count() {
+		return false, fmt.Errorf("invalid prefix key (%d < %d)", preKey.Count(), preDesc.Count())
+	} else if m.keyDesc.Count() < preDesc.Count() {
+		return false, fmt.Errorf("invalid TupleDesc prefix (%d < %d)", m.keyDesc.Count(), preDesc.Count())
+	}
+	return m.tuples.HasPrefix(ctx, preKey, preDesc)
+}
+
 // IterRange returns a mutableMapIter that iterates over a Range.
 func (m Map) IterRange(ctx context.Context, rng Range) (MapIter, error) {
-	if rng.IsPointLookup(m.keyDesc) {
-		return m.pointLookupFromRange(ctx, rng)
-	}
-
 	iter, err := treeIterFromRange(ctx, m.tuples.Root, m.tuples.NodeStore, rng)
 	if err != nil {
 		return nil, err
@@ -332,49 +329,14 @@ func (m Map) CompareItems(left, right tree.Item) int {
 	return m.keyDesc.Compare(val.Tuple(left), val.Tuple(right))
 }
 
-func (m Map) pointLookupFromRange(ctx context.Context, rng Range) (*pointLookup, error) {
-	cur, err := tree.NewCursorFromSearchFn(ctx, m.tuples.NodeStore, m.tuples.Root, rangeStartSearchFn(rng))
-	if err != nil {
-		return nil, err
-	}
-	if !cur.Valid() {
-		// map does not contain |rng|
-		return &pointLookup{}, nil
-	}
-
-	key := val.Tuple(cur.CurrentKey())
-	value := val.Tuple(cur.CurrentValue())
-
-	if !rng.Matches(key) {
-		return &pointLookup{}, nil
-	}
-
-	return &pointLookup{k: key, v: value}, nil
-}
-
 func treeIterFromRange(
 	ctx context.Context,
 	root tree.Node,
 	ns tree.NodeStore,
 	rng Range,
 ) (*tree.OrderedTreeIter[val.Tuple, val.Tuple], error) {
-	var (
-		err   error
-		start *tree.Cursor
-		stop  *tree.Cursor
-	)
-
-	start, err = tree.NewCursorFromSearchFn(ctx, ns, root, rangeStartSearchFn(rng))
-	if err != nil {
-		return nil, err
-	}
-
-	stop, err = tree.NewCursorFromSearchFn(ctx, ns, root, rangeStopSearchFn(rng))
-	if err != nil {
-		return nil, err
-	}
-
-	return tree.OrderedTreeIterFromCursors[val.Tuple, val.Tuple](start, stop), nil
+	findStart, findStop := rangeStartSearchFn(rng), rangeStopSearchFn(rng)
+	return tree.OrderedTreeIterFromCursors[val.Tuple, val.Tuple](ctx, root, ns, findStart, findStop)
 }
 
 func NewPointLookup(k, v val.Tuple) *pointLookup {
